@@ -32,7 +32,7 @@ var NAVTREE =
       [ "Installing the binaries on Windows", "install.html#install_bin_windows", null ]
     ] ],
     [ "Getting started", "starting.html", [
-      [ "Step 0: Check if doxygen supports your programming language", "starting.html#step0", null ],
+      [ "Step 0: Check if doxygen supports your programming/hardware description language", "starting.html#step0", null ],
       [ "Step 1: Creating a configuration file", "starting.html#step1", null ],
       [ "Step 2: Running doxygen", "starting.html#step2", [
         [ "HTML output", "starting.html#html_out", null ],
@@ -79,7 +79,8 @@ var NAVTREE =
         [ "Table of Contents", "markdown.html#md_toc", null ],
         [ "Tables", "markdown.html#md_tables", null ],
         [ "Fenced Code Blocks", "markdown.html#md_fenced", null ],
-        [ "Header Id Attributes", "markdown.html#md_header_id", null ]
+        [ "Header Id Attributes", "markdown.html#md_header_id", null ],
+        [ "Image Attributes", "markdown.html#md_image_attributes", null ]
       ] ],
       [ "Doxygen specifics", "markdown.html#markdown_dox", [
         [ "Including Markdown files as pages", "markdown.html#md_page_header", null ],
@@ -91,7 +92,7 @@ var NAVTREE =
         [ "Use of asterisks", "markdown.html#mddox_stars", null ],
         [ "Limits on markup scope", "markdown.html#mddox_limits", null ]
       ] ],
-      [ "Debugging of problems", "markdown.html#markdown_debug", null ]
+      [ "Debugging problems", "markdown.html#markdown_debug", null ]
     ] ],
     [ "Lists", "lists.html", null ],
     [ "Grouping", "grouping.html", [
@@ -268,6 +269,7 @@ var NAVTREE =
       [ "\\deprecated { description }", "commands.html#cmddeprecated", null ],
       [ "\\details { detailed description }", "commands.html#cmddetails", null ],
       [ "\\noop ( text to be ignored )", "commands.html#cmdnoop", null ],
+      [ "\\raisewarning ( text to be shown as warning )", "commands.html#cmdraisewarning", null ],
       [ "\\else", "commands.html#cmdelse", null ],
       [ "\\elseif (section-label)", "commands.html#cmdelseif", null ],
       [ "\\endcond", "commands.html#cmdendcond", null ],
@@ -410,12 +412,14 @@ var NAVTREE =
         [ "Creation of PDF and DVI output", "perlmod.html#pm_pdf_gen", null ]
       ] ],
       [ "Documentation format.", "perlmod.html#doxydocs_format", null ],
-      [ "Data structure", "perlmod.html#doxymodel_format", null ]
+      [ "Data structure", "perlmod.html#doxymodel_format", null ],
+      [ "Perl Module Tree Nodes", "perlmod.html#perlmod_tree", null ]
     ] ],
-    [ "Perl Module Tree Nodes", "perlmod_tree.html", null ],
     [ "Doxygen's Internals", "arch.html", null ],
     [ "Changelog", "changelog.html", [
       [ "1.9 Series", "changelog.html#log_1_9", [
+        [ "Release 1.9.4", "changelog.html#log_1_9_4", null ],
+        [ "Release 1.9.3", "changelog.html#log_1_9_3", null ],
         [ "Release 1.9.2", "changelog.html#log_1_9_2", null ],
         [ "Release 1.9.1", "changelog.html#log_1_9_1", null ],
         [ "Release 1.9.0", "changelog.html#log_1_9_0", null ]
@@ -461,7 +465,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "arch.html",
-"config.html#config_external"
+"config.html#config_docbook"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
